#!/bin/bash
trap 'sigterm_handler' 15

sigterm_handler()
{
	echo "Handle sigterm(15) signal." 1> /dev/null 2>&1
}

AUDIT_DISPATCHER_PLUGINS_DIR="/etc/audisp/plugins.d"
AUDIT_FIM_PLUGIN_CONF="${AUDIT_DISPATCHER_PLUGINS_DIR}/fim-plugin.conf"
FIM_POLICY_NAME="fim-plugin-policy"

# To check auditd version is above 3.0 or not
# above 3.0 auditd version plugin configuration directory locations are changed.
AUDITD_MAJOR_VERSION="1"

if [ `whoami` != "root" ]; then
	echo "run as root or sudo user." >&2
    exit 2
fi

## explictly adding /usr/sbin and /usr/bin in path and command used here and from these path.
export PATH=$PATH:/usr/sbin:/usr/bin

#check auditctl exists or not
which auditctl 1> /dev/null 2>&1
if [ $? == 0 ]; then
	AUDITD_MAJOR_VERSION=`auditctl -v|awk -F " " '{print $3}'|sed -n 's/\([0-9]\+\).*/\1/p'`
fi
reload_auditd()
{

        AUDITDPID=`pgrep auditd -x`
        if [ -z "${AUDITDPID}" ]; then
        	echo "ERROR : auditd is not running" >&2
        else
           echo "auditd is running, reloading configuration" 1> /dev/null 2>&1
			service auditd restart 1> /dev/null 2>&1
        fi

}

unload_fimplugin_policy()
{

which sestatus;
if [ $? == 0 ]; then
	selinuxStatus=`sestatus|grep "SELinux status"|awk -F" " '{print $3}'`;
	if [ ! -z "$selinuxStatus" ]; then
		selinuxStatus=`echo $selinuxStatus|tr '[:upper:]' '[:lower:]'`
		if [ "$selinuxStatus" == "disabled" ]; then
			return 1;
		elif [ "$selinuxStatus" == "enabled" ]; then
			#check for current mode .
			selinuxStatus=`sestatus|grep "Current mode"|awk -F" " '{print $3}'`
			selinuxStatus=`echo $selinuxStatus|tr '[:upper:]' '[:lower:]'`
			if [ "$selinuxStatus" == "disabled" ]; then
				return 1;
			fi
		fi
		which semodule;
		if [ $? != 0 ]; then
			return 1;
		fi
		nohup semodule -r "${FIM_POLICY_NAME}" 1> /dev/null 2>&1 &
	fi
fi
}

# If auditd version is greater than or equal to 3.0 then reconfigure Plugin directory loc.
if [ "$AUDITD_MAJOR_VERSION" -ge 3 ] ; then
	#re-initialised FIM_PLUGIN_CONF PATH.
	AUDIT_DISPATCHER_PLUGINS_DIR="/etc/audit/plugins.d"
	AUDIT_FIM_PLUGIN_CONF="${AUDIT_DISPATCHER_PLUGINS_DIR}/fim-plugin.conf"
fi

#remove previous install if there and reload audisp or previous binary will be busy and prevent overwriting
#copy audisp plugin bnary

if [ -f "$AUDIT_FIM_PLUGIN_CONF" ]; then
echo "Removing $AUDIT_FIM_PLUGIN_CONF"
rm -rf "$AUDIT_FIM_PLUGIN_CONF"
reload_auditd
fi

if [ "$#" -ge 1 ]; then
	if [ "$1" == "unload_policy" ]; then
		unload_fimplugin_policy
	fi
fi

exit 0
